@@ -14,37 +14,31 @@
    
 extern "C" {
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-// Calculating mean for copula function
+// Computing mean for copula function
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void get_mean( double Z[], double K[], double *mu_ij, double *sigma, int *i, int *j, int *n, int *p )
 {
     int k, dim = *p, number = *n, row = *i, col = *j, jxp = col * dim;
     double mu = 0.0;
     
-    for( k = 0; k < col; k++ ) 
-        mu += Z[ k * number + row ] * K[ jxp + k ];
-    
-    for( k = col + 1; k < dim; k++ ) 
-        mu += Z[ k * number + row ] * K[ jxp + k ];
+    for( k = 0;       k < col; k++ ) mu += Z[ k * number + row ] * K[ jxp + k ];
+    for( k = col + 1; k < dim; k++ ) mu += Z[ k * number + row ] * K[ jxp + k ];
     
     *mu_ij = - mu * *sigma;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-// Calculating bounds for copula function
+// Computing bounds for copula function
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void get_bounds( double Z[], int R[], double *lb, double *ub, int *i, int *j, int *n )
 {
-    int kj, ij, row = *i, col = *j;
+    int kj, col = *j, number = *n, ij = col * number + *i;
     double low_b = -1e308, upper_b = +1e308;
     
-    for( int k = 0, number = *n; k < number; k++ )
+    for( int k = 0; k < number; k++ )
     {
         kj = col * number + k;
-        ij = col * number + row;
         
-        // if( R[k, j] < R[i, j] ) lb = max( Z[ k, j], lb )
-        // if( R[k, j] > R[i, j] ) ub = min( Z[ k, j], ub )										
         if( R[ kj ] < R[ ij ] ) 
             low_b = max( Z[ kj ], low_b );	
         else if( R[ kj ] > R[ ij ] ) 
@@ -56,14 +50,13 @@ void get_bounds( double Z[], int R[], double *lb, double *ub, int *i, int *j, in
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-// copula part
+// copula for BDMCMC sampling algorithm
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void copula( double Z[], double K[], int R[], int not_continuous[], int *n, int *p )
 {
     int number = *n, dim = *p, dimp1 = dim + 1, i, j, jxn;
     double sigma, sd_j, mu_ij, lb, ub, runif_value, pnorm_lb, pnorm_ub;
     
-    //GetRNGstate();
     for( j = 0; j < dim; j++ )
     {
         if( not_continuous[ j ] )
@@ -87,26 +80,22 @@ void copula( double Z[], double K[], int R[], int not_continuous[], int *n, int
             }
         }
     }
-    //PutRNGstate();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-// Calculating bounds for copula function with missing data 
+// Computing bounds for copula function for data with missing values 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void get_bounds_NA( double Z[], int R[], double *lb, double *ub, int *i, int *j, int *n )
 {
-    int kj, ij, row = *i, col = *j;
+    int kj, number = *n, col = *j, ij = col * number + *i;
     double low_b = -1e308, upper_b = +1e308;
     
-    for( int k = 0, number = *n; k < number; k++ )
+    for( int k = 0; k < number; k++ )
     {
         kj = col * number + k;
-        ij = col * number + row;
         
-        if( R[kj] != 0 )
+        if( R[ kj ] != 0 )
         {
-            // if( R[k, j] < R[i, j] ) lb = max( Z[ k, j], lb )
-            // if( R[k, j] > R[i, j] ) ub = min( Z[ k, j], ub )										
             if( R[ kj ] < R[ ij ] ) 
                 low_b = max( Z[ kj ], low_b );	
             else if( R[ kj ] > R[ ij ] ) 
@@ -119,13 +108,12 @@ void get_bounds_NA( double Z[], int R[], double *lb, double *ub, int *i, int *j,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-// copula part for missing data
+// copula for data with missing values 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void copula_NA( double Z[], double K[], int R[], int not_continuous[], int *n, int *p )
 {
     int number = *n, dim = *p, nxp = number * dim, dimp1 = dim + 1;
     
-    //GetRNGstate();
     #pragma omp parallel
     {	
         double sigma, sd_j, mu_ij, lb, ub, runif_value, pnorm_lb, pnorm_ub;
@@ -142,7 +130,7 @@ void copula_NA( double Z[], double K[], int R[], int not_continuous[], int *n, i
             
             get_mean( Z, K, &mu_ij, &sigma, &i, &j, &number, &dim );
             
-            if( R[counter] != 0 )
+            if( R[ counter ] != 0 )
             {
                 get_bounds_NA( Z, R, &lb, &ub, &i, &j, &number );
                 
@@ -151,12 +139,10 @@ void copula_NA( double Z[], double K[], int R[], int not_continuous[], int *n, i
                 //runif_value = runif( pnorm_lb, pnorm_ub );
                 runif_value  = pnorm_lb + unif_rand() * ( pnorm_ub - pnorm_lb );
                 Z[ counter ] = Rf_qnorm5( runif_value, mu_ij, sd_j, TRUE, FALSE );
-            } 
-            else 
-                Z[ counter ] = mu_ij + norm_rand() * sd_j;  // Z[counter] = rnorm( mu_ij, sd_j );
+            }else
+                Z[ counter ] = mu_ij + norm_rand() * sd_j;  // rnorm( mu_ij, sd_j );
         }
     }
-    //PutRNGstate();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
@@ -164,23 +150,14 @@ void copula_NA( double Z[], double K[], int R[], int not_continuous[], int *n, i
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void get_S( double K[], double Z[], int R[], int not_continuous[], double S[], int *gcgm, int *n, int *p )
 {
-    //GetRNGstate();
-    // int gcgm_check = *gcgm, dim = *p, pxp = dim * dim;
     int dim = *p;
     
-	//if( gcgm_check == 0 ) copula( Z, K, R, n, &dim ); else	copula_NA( Z, K, R, n, &dim );
 	( *gcgm == 0 ) ? copula( Z, K, R, not_continuous, n, &dim ) : copula_NA( Z, K, R, not_continuous, n, &dim );
 	
-	//for( int i = 0; i < ( dim * dim ); i++ ) S[ i ] = 0.0;
-	
-	// S <- t(Z) %*% Z
-	// Here, I'm using Ds instead of S, for saving memory
+	// S <- t(Z) %*% Z; NOTE, I'm using Ds instead of S, for saving memory
 	double alpha = 1.0, beta  = 0.0;
 	char transA = 'T', transB = 'N';
-	// LAPACK function to compute  C := alpha * A * B + beta * C
-	//        DGEMM ( TRANSA,  TRANSB, M, N, K,  ALPHA, A,LDA,B, LDB,BETA, C, LDC )	
 	F77_NAME(dgemm)( &transA, &transB, &dim, &dim, n, &alpha, Z, n, Z, n, &beta, S, &dim );	
-	//PutRNGstate();
 }
-
+   
 } // End of exturn "C"
